# frozen_string_literal: true

# Generated via
#  `rails generate hyrax:work_resource Crc1280Experiment`
module Hyrax
  # Generated controller for Crc1280Experiment
  class Crc1280ExperimentsController < ApplicationController
    # Adds Hyrax behaviors to the controller.
    include Hyrax::WorksControllerBehavior
    include Hyrax::BreadcrumbsForWorks
    self.curation_concern_type = ::Crc1280Experiment

    # Use a Valkyrie aware form service to generate Valkyrie::ChangeSet style
    # forms.
    self.work_form_service = Hyrax::FormFactory.new

    # Use this line if you want to use a custom presenter
    self.show_presenter = Hyrax::Crc1280ExperimentPresenter

    before_action :authorize_collection_access, only: :new
    before_action :check_tombstone,  only: [:show, :edit]
    before_action :redirect_to_default_collection, only:[:new]

    def authorize_collection_access
      group_id = params[:add_works_to_collection]

      if current_user.admin? || current_user.crc_manager_for?(group_id) || current_user.group_manager_for?(group_id) || current_user.group_member_for?(group_id)
        return true
      end

      redirect_to root_path

      flash[:alert] = 'You are not authorized to access this page.'
    end


    def new
      @admin_set_options = available_admin_sets
      # TODO: move these lines to the work form builder in Hyrax
      curation_concern.depositor = current_user.user_key
      curation_concern.admin_set_id = admin_set_id_for_new
      curation_concern.crc_work_type = 'experiment'
      build_form
    end

    private

    def check_tombstone
      @crc1280_experiment = Crc1280Experiment.find(params[:id])
      if current_user.present? && (current_user.publication_manager? || current_user.admin?)
        if @crc1280_experiment.is_tombstoned == true && params[:action] == 'edit'
          redirect_to main_app.polymorphic_path(@crc1280_experiment)
        end
      else
        if @crc1280_experiment.is_tombstoned == true
          flash[:notice] = 'The work (dataset) is not available because it has Tombstoned'
          render 'shared/tombstone', locals: {work: @crc1280_experiment}, status: :unauthorized
        end
      end
    end

    def redirect_to_default_collection
      return if params.has_key?(:add_works_to_collection)

      collection = Hyrax::PcdmCollection.find_by(title: [ENV.fetch('CRC_1280_COLLECTION', "CRC 1280")])

      flash[:notice] = "You need to navigate to your group to create an experiment."
      redirect_to dashboard_collection_path(collection.id)
    end
 
    def build_breadcrumbs
      return super if ['show', 'edit'].exclude?(action_name)
      work = Crc1280Experiment.find(presenter.id)
      parent_group_collection = work.parent_collections.first
      crc_1280_collection =  parent_group_collection.parent_collections.first if parent_group_collection

      add_breadcrumb t(:'hyrax.controls.home'), root_path
      add_breadcrumb crc_1280_collection.title.first, dashboard_collection_path(crc_1280_collection.id) if crc_1280_collection.present?
      add_breadcrumb parent_group_collection.title.first, dashboard_collection_path(parent_group_collection.id) if parent_group_collection.present?
      add_breadcrumb_for_action
    end
  end
end
