# frozen_string_literal: true

module PopulatorBehavior

  private
  def complex_person_populator(fragment:, **_options)
    adds = []
    deletes = []

    fragment.each do |_, h|
      person_hash = h.slice("role", "orcid", "last_name", "first_name", "affiliation")
      person_hash = person_hash.permit!.to_h.to_hash if person_hash.is_a?(ActionController::Parameters)
      person_hash = person_hash.transform_keys(&:to_sym) 
      if h["_destroy"] == "1"
        deletes << person_hash
      else
        if !all_values_empty?(person_hash) && validate_complax_person?(person_hash)
          adds << person_hash
        end
      end
    end
  
    # Add elements in `adds` to `complex_person`
    updated_persons = complex_person + adds
  
    # Remove elements in `deletes` from `updated_persons`
    remaining_persons = updated_persons.reject do |person|
      deletes.any? do |delete_person|
        delete_person == person
      end
    end
    self.complex_person = remaining_persons.uniq
  end

  def complex_funding_reference_populator(fragment:, **_options)
    adds = []
    deletes = []
  
    fragment.each do |_, h|
      reference_hash = h.slice("funder_identifier", "funder_name", "award_number", "award_uri", "award_title")
      reference_hash = reference_hash.permit!.to_h.to_hash if reference_hash.is_a?(ActionController::Parameters)
      reference_hash = reference_hash.transform_keys(&:to_sym) 
      if h["_destroy"] == "1"
        deletes << reference_hash
      elsif !all_values_empty?(reference_hash)
        adds << reference_hash
      end
    end
    # Add elements in `adds` to `complex_funding_reference`
    updated_references = complex_funding_reference + adds
  
    # Remove elements in `deletes` from `updated_reference`
    remaining_references = updated_references.reject do |reference|
      deletes.any? do |delete_reference|
        delete_reference == reference
      end
    end

    self.complex_funding_reference = remaining_references.uniq
  end

  def complex_relation_populator(fragment:, **_options)
    adds = []
    deletes = []
  
    fragment.each do |_, h|
      relation_hash = h.slice("title", "url", "relationship")
      relation_hash = relation_hash.permit!.to_h.to_hash if relation_hash.is_a?(ActionController::Parameters)
      relation_hash = relation_hash.transform_keys(&:to_sym)
      if h["_destroy"] == "1"
        deletes << relation_hash
      elsif !all_values_empty?(relation_hash)
        adds << relation_hash
      end
    end
    # Add elements in `adds` to `complex_relation`
    updated_relations = complex_relation + adds
  
    # Remove elements in `deletes` from `updated_relation`
    remaining_relations = updated_relations.reject do |relation|
      deletes.any? do |delete_relation|
        delete_relation == relation
      end
    end

    self.complex_relation = remaining_relations.uniq
  end

  def complex_date_populator(fragment:, **_options)
    adds = []
    deletes = []

    fragment.each do |_, h|
      date_hash = h.slice("date", "description")
      date_hash = date_hash.permit!.to_h.to_hash if date_hash.is_a?(ActionController::Parameters)
      date_hash = date_hash.transform_keys(&:to_sym)
      if h["_destroy"] == "1"
        deletes << date_hash
      elsif !all_values_empty?(date_hash)
        adds << date_hash
      end
    end
    # Add elements in `adds` to `complex_date`
    updated_dates = complex_date + adds
  
    # Remove elements in `deletes` from `updated_date`
    remaining_dates = updated_dates.reject do |date|
      deletes.any? do |didentifierselete_date|
        delete_date == date
      end
    end

    self.complex_date = remaining_dates.uniq
  end

  def complex_identifier_populator(fragment:, **_options)
    adds = []
    deletes = []
  
    fragment.each do |_, h|
      identifier_hash = h.slice("identifier", "scheme","label")
      identifier_hash = identifier_hash.permit!.to_h.to_hash if identifier_hash.is_a?(ActionController::Parameters)
      identifier_hash = identifier_hash.transform_keys(&:to_sym)
      if h["_destroy"] == "1"
        deletes << identifier_hash
      elsif !all_values_empty?(identifier_hash)
        adds << identifier_hash
      end
    end
    # Add elements in `adds` to `complex_identifier`
    updated_identifiers = complex_identifier + adds
  
    # Remove elements in `deletes` from `updated_identifier`
    remaining_identifiers = updated_identifiers.reject do |identifier|
      deletes.any? do |delete_identifier|
        delete_identifier == identifier
      end
    end

    self.complex_identifier = remaining_identifiers.uniq
  end 

  def complex_funding_reference_prepopulator
    self.complex_funding_reference =  [{
      funder_identifier: ENV['CRCDATASET_FUNDER_IDENTIFIER'],
      funder_name: ENV['CRCDATASET_FUNDER_NAME'],
      award_title: ENV['CRCDATASET_AWARD_TITLE'],
      award_number: ENV['CRCDATASET_AWARD_NUMBER'],
      award_uri: ENV['CRCDATASET_AWARD_URI']
    }]
  end 


  def validate_complax_person?(person_hash)
    person_hash[:first_name].present? && person_hash[:last_name].present? && person_hash[:role].present?
  end

  def all_values_empty?(data_hash)
    data_hash.values.flatten.all?(&:empty?)
  end
end