module Hyrax
  module Listeners
    module LifecycleListenerHelper
      def after_create_callbacks(object)
        user ||= ::User.find_by_user_key(object.depositor)
        case object.class.name
        when 'Crc1280Experiment'
          object = set_default_source_and_tombstone_status(object)
          object = set_crc1280_experiment_default_values(object)
          object = object.apply_parent_permissions
          object = object.register_ark(user: user)
        when 'Dataset'
          object = set_default_source_and_tombstone_status(object)
          object = object.register_ark(user: user)
        end

        object.save
        object.save_index
        object
      end

      def before_save_callbacks(object)
        case object.class.name
        when 'Crc1280Experiment', 'Dataset'
          object = object.set_format_and_size
        end

        object.save
        object.save_index
        object
      end

      def after_save_callbacks(object)
        case object.class.name
        when 'Crc1280Experiment'
          object.save_metadata_as_json_in_s3
          object.save_meta_json_in_s3
        when 'Dataset'
          object.save_metadata_as_json_in_s3
        end

        object
      end

      def after_destroy_callbacks(object)
        case object.class.name
        when 'Crc1280Experiment', 'Dataset'
          object.clear_s3_and_all_associated_objects
        when 'FileSet'
          destroy_set_meta_data(object)
        end
      end

      private

      def set_default_source_and_tombstone_status(object)
        object.source = object.source.present? ? object.source : [SecureRandom.uuid]
        object.is_tombstoned = false
        object
      end

      def set_crc1280_experiment_default_values(object)
        object.language = [ENV['CRCDATASET_LANGUAGE']] unless object.language.present?
        object.resource_type = [ENV['CRCDATASET_RESOURCE_TYPE']] unless object.resource_type.present?
        object
      end

      def destroy_set_meta_data(object)
        s3 = S3StorageService.new
        s3.init_client
        bucket_name = s3.sanitise_name(object.parent.id)
        meta_data.destroy! if meta_data.present?
    
        s3.delete_object(bucket_name, self.object_key_on_s3)
        parent.update(date_modified: DateTime.now)
      end
    end
  end
end