module S3FileHandler

  def move_and_remove_files_on_s3(object_class_name, object_id, name_changes)
    target_object = object_class_name.constantize.find_by(id: object_id)

    @s3 = S3StorageService.new
    @s3.init_client
    @bucket_name = @s3.sanitise_name(target_object.crc1280_experiment.id)
    @objects_prefix = objects_prefix(target_object, name_changes[0])

    all_objects, size = @s3.list_all_objects(@bucket_name, @objects_prefix)

    if all_objects.any?
      all_objects.each do |object|
        source_object_key = object[:key]
        target_object_key = source_object_key.gsub(name_changes[0], name_changes[1])

        if meta_files_keys.include?(source_object_key)
          delete_metadata_files(source_object_key)
        else
          move_object(source_object_key, target_object_key)
        end
      end
    end
  end

  def objects_prefix(object, previous_name)
    case object.class.name
    when 'ComplexSubject'
      "#{object.crc1280_experiment.id.to_s}/#{previous_name}/"
    when 'ComplexSession'
      "#{object.crc1280_experiment.id.to_s}/#{object.complex_subject.s3_folder_name}/#{previous_name}/"
    when 'ComplexModality'
      "#{object.crc1280_experiment.id.to_s}/#{object.complex_subject.s3_folder_name}/#{object.complex_session.s3_folder_name}/#{previous_name}/"
    end
  end

  def meta_files_keys
    [
      "#{@objects_prefix}metadata.json",
      "#{@objects_prefix}system_metadata.json",
      "#{@objects_prefix}meta.json"
    ]
  end

  def move_object(source_object_key, target_object_key)
    if @s3.object_exists?(@bucket_name, source_object_key)
      @s3.move_object(source_object_key, @bucket_name, target_object_key, {}, @bucket_name)
    end
  end

  def delete_metadata_files(object_key)
    @s3.delete_object(@bucket_name, object_key)
  end
end
