module ComplexField
  module SessionIndexer
    def to_solr
      super.tap do |index_document|
        index_session(index_document)
      end
    end

    def index_session(index_document)
      complex_sessions = resource.complex_subjects.map{|subject| subject.complex_sessions}.flatten
      index_document["complex_session_ssm"] = complex_sessions.to_json

      complex_sessions.each do |c|
        # session_titles
        vals = c.session_title
        fld_name = "session_tesim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        fld_name = "session_sim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq

        # date_recorded as date
        unless c.session_date_recorded.blank?
          vals =  c.session_date_recorded.strftime("%Y-%m-%d")
          fld_name = "date_recorded_dtsim"
          index_document[fld_name] = [] unless index_document.include?(fld_name)
          begin
            dates_utc = vals.tr('０-９ａ-ｚＡ-Ｚ', '0-9a-zA-Z')
            dates_utc = (dates_utc.length <= 4 ? DateTime.strptime(dates_utc, '%Y').utc.iso8601 : DateTime.parse(dates_utc).utc.iso8601) unless vals.blank?
          rescue ArgumentError
            dates_utc = vals.tr('０-９ａ-ｚＡ-Ｚ', '0-9a-zA-Z')
            dates_utc = DateTime.parse("#{dates_utc}-01").utc.iso8601 unless vals.blank?
          end
          # as date
          index_document[fld_name] << dates_utc unless dates_utc.blank?
          index_document[fld_name].flatten!
          # Add years
          year_fld = "year_recorded_sim"
          years = DateTime.parse(dates_utc).strftime("%Y") unless dates_utc.blank?
          index_document[year_fld] = [] unless index_document.include?(year_fld)
          index_document[year_fld] << years unless years.blank?
          index_document[year_fld].flatten!
          # date as displayable
          fld_name = "date_recorded_ssm"
          index_document[fld_name] = [] unless index_document.include?(fld_name)
          index_document[fld_name] << vals
          index_document[fld_name].flatten!
        end
      end
    end

    def self.session_facet_fields
      # solr fields that will be treated as facets
      fields = []
      fields << "session_sim"
      fields << "year_recorded_sim"
      fields << "date_recorded_dtsim"
      fields
    end

    def self.session_search_fields
      # solr fields that will be used for a search
      fields = []
      fields << "session_title_ssim"
      fields << "session_tesim"
      fields << "date_recorded_dtsim"
      fields
    end

    def self.session_show_fields
      # solr fields that will be used to display results on the record page
      fields = []
      fields << "complex_session_ssm"
      fields
    end
  end
end
