module ComplexField
  module SubjectIndexer
    def to_solr
      super.tap do |index_document|
        index_subject(index_document)
      end
    end

    def index_subject(index_document)
      index_document["complex_subject_ssm"] = resource.complex_subjects.to_json
      resource.complex_subjects.each do |c|
        # species
        vals = [c.subject_species]

        fld_name = "complex_subject_species_tesim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        fld_name = "complex_subject_species_sim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq

        # type
        vals = [c.subject_type]
        fld_name = "complex_subject_type_tesim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        fld_name = "complex_subject_type_sim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq

        # sex
        vals = [c.subject_sex]
        fld_name = "complex_subject_sex_tesim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        fld_name = "complex_subject_sex_sim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq

        # age
        vals = [c.subject_age]
        fld_name = "complex_subject_age_tesim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        fld_name = "complex_subject_age_sim"
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
        # for integer range queries
        fld_name = 'complex_subject_age_itsim'
        int_vals = []
        vals.each do |v|
          int_vals << Integer(v) if Integer === Integer(v, exception: false)
        end
        index_document[fld_name] = [] unless index_document.include?(fld_name)
        index_document[fld_name] << int_vals
        index_document[fld_name] = index_document[fld_name].flatten.uniq
      end
    end

    def self.subject_facet_fields
      # solr fields that will be treated as facets
      fields = []
      fields << "complex_subject_species_sim"
      fields << "complex_subject_type_sim"
      fields << "complex_subject_sex_sim"
      fields << 'complex_subject_age_itsim'
      fields
    end

    def self.subject_search_fields
      # solr fields that will be used for a search
      fields = []
      fields << "complex_subject_species_tesim"
      fields << "complex_subject_type_tesim"
      fields << "complex_subject_sex_tesim"
      fields << "complex_subject_age_tesim"
      fields
    end

    def self.subject_show_fields
      # solr fields that will be used to display results on the record page
      fields = []
      fields << "complex_subject_ssm"
      fields
    end
  end
end
