# frozen_string_literal: true
module Hyrax
  class RemoveAssociatedObjectsJob < ApplicationJob
    def perform(work_id, user_id)
      user = ::User.find(user_id)
      work = Hyrax.query_service.find_by(id: work_id)

      work.file_sets.each do |file_set|
        transactions = Hyrax::Transactions::Container

        transactions['file_set.destroy']
          .with_step_args('file_set.remove_from_work' => { user: user },
                          'file_set.delete' => { user: user })
          .call(file_set)
          .value!
      end

      work.complex_subjects.destroy_all if work.is_a?(Crc1280Experiment)

      s3 = S3StorageService.new
      s3.init_client
      bucket_name = s3.sanitise_name(ENV['S3_FILE_UPLOAD_BUCKET'])
      objects, size = s3.list_all_objects(bucket_name, work_id)

      s3.delete_objects(bucket_name, objects.map{ |obj| obj[:key]})
    end
  end
end