class Ability
  include Hydra::Ability
  
  include Hyrax::Ability
  self.ability_logic += %i[
    everyone_can_create_curation_concerns
    manage_roles
    manage_importer
    manage_exporter
  ]

  # Define any customized permissions here.
  def custom_permissions
    return unless current_user.admin?

    can :manage, Role
    can :manage, User
    can :create, [::Dataset, ::Crc1280Experiment]
  end

  def create_content
    return unless current_user

    can [:confirm_delete, :restore], [::Dataset, ::Crc1280Experiment] if current_user.admin? || current_user.crc_manager?
    can [:create, :tombstone], [::Dataset, ::Crc1280Experiment]
  end

  def manage_roles
    can %i[edit update show add_user remove_user], Role do |role|
      if role.is_crc_manager
        current_user.roles.where(name: role.name).any?
      elsif role.is_crc_member
        current_user.roles.where(name: role.name.gsub('_member', '_manager')).any?
      elsif role.is_crc_group_manager
        current_user.crc_manager_for?(role.name.split('_')[-2])
      elsif role.is_crc_group_member
        group_id = role.name.split('_')[-2]

        current_user.crc_manager_for?(group_id) || current_user.group_manager_for?(group_id)
      else
        false
      end
    end
  end

  def manage_importer
    return unless current_user.admin? || current_user.roles.where(is_crc_manager: true).present?

    can [:manage, :show], Bulkrax::Importer
  end

  def manage_exporter
    return unless current_user.admin? || current_user.roles.where(is_crc_manager: true).present?

    can [:manage, :show], Bulkrax::Exporter
  end

  def can_import_works?
    can_create_any_work?
  end

  def can_export_works?
    can_create_any_work?
  end
end
