# frozen_string_literal: true

module Bulkrax
  class Crc1280ExperimentCreatedError < RuntimeError; end
  class ComplexSubjectCreatedError < RuntimeError; end
  class ComplexSessionCreatedError < RuntimeError; end

  class CrcFolderEntry < CsvEntry
    def build_metadata
      validate_record

      self.parsed_metadata = {}
      add_identifier
      establish_factory_class
      add_ingested_metadata
      # TODO(alishaevn): remove the collections stuff entirely and only reference collections via the new parents code
      add_collections
      add_visibility
      add_metadata_for_model
      add_rights_statement
      add_local
      sanitize_controlled_uri_values!

      self.parsed_metadata
    end

    def add_metadata_for_model
      if factory_class == Collection
        add_collection_type_gid
      elsif factory_class == Hyrax::FileSet
        validate_presence_of_filepath!
        validate_existence_of_file
        validate_presence_of_parent!
      else
        add_file unless importerexporter.metadata_only?
        add_admin_set_id
      end
    end
  end
end
