# frozen_string_literal: true

# Represents a single document returned from Solr
class SolrDocument
  include Blacklight::Solr::Document
  include Blacklight::Gallery::OpenseadragonSolrDocument

  # Adds Hyrax behaviors to the SolrDocument.
  include Hyrax::SolrDocumentBehavior


  # self.unique_key = 'id'

  # Email uses the semantic field mappings below to generate the body of an email.
  SolrDocument.use_extension(Blacklight::Document::Email)

  # SMS uses the semantic field mappings below to generate the body of an SMS email.
  SolrDocument.use_extension(Blacklight::Document::Sms)

  # DublinCore uses the semantic field mappings below to assemble an OAI-compliant Dublin Core document
  # Semantic mappings of solr stored fields. Fields may be multi or
  # single valued. See Blacklight::Document::SemanticFields#field_semantics
  # and Blacklight::Document::SemanticFields#to_semantic_values
  # Recommendation: Use field names from Dublin Core
  use_extension(Blacklight::Document::DublinCore)

  # Do content negotiation for AF models. 

  use_extension( Hydra::ContentNegotiation )

  def crc_collection_type
    self["crc_collection_type_tesim"]&.first
  end

  def tombstone_status
    self["tombstone_status_ssim"]
  end

  def is_tombstoned
    self["is_tombstoned_ssim"]
  end

  def tombstone_date
    self["tombstone_date_ssim"]
  end

  def proxy_depositor
    self["proxy_depositor_ssim"]
  end


  def crc_resource_type
    self["crc_resource_type_tesim"]
  end

  def crc_work_type
    self["crc_work_type_tesim"]
  end

  def experiment_description
    self["experiment_description_tesim"]
  end

  def complex_date
    self["complex_date_ssm"]
  end

  def complex_funding_reference
    self["complex_funding_reference_ssm"]
  end

  def complex_identifier
    self["complex_identifier_ssm"]
  end

  def complex_person
    self["complex_person_ssm"]
  end

  def complex_relation
    self["complex_relation_ssm"]
  end

  def coverage
    self["coverage_tesim"]
  end

  def approval_number
    self["approval_number_ssim"]
  end

  def extra_information
    self["extra_information_tesim"]
  end

  def doi
    self["doi_ssim"]
  end

  def software_version
    self["software_version_tesim"]
  end

  def for_complex_identifier
    self["for_complex_identifier_tesim"]
  end

  def for_complex_type
    self["for_complex_type_tesim"]
  end

  def sipity_entity
    @sipity_entity ||= Sipity::Entity(self)
  end

  def workflow_state
    sipity_entity.workflow_state.name
  end
end
