require 'net/http'

class DoiService
  def initialize(work_id)
    @work_id = work_id
  end

  def register_doi_and_update_work
    attributes = register_doi
    update_work(attributes)
  end

  def register_doi
    @work = Hyrax.query_service.find_by(id: @work_id)

    url = URI(ENV['DOI_URL'])

    http = Net::HTTP.new(url.host, url.port)
    http.use_ssl = true
    creators_hash = @work.complex_person.map do |person|
      { name: "#{person["last_name"]},#{person["first_name"]}" }
    end.compact

    request = Net::HTTP::Post.new(url)
    request['content-type'] = 'application/vnd.api+json'
    request.basic_auth ENV['DOI_USERNAME'], ENV['DOI_PASSWORD']

    body = {
      "data": {
        "id": "#{ENV['DOI_PREFIX']}/#{@work.id}",
        "type": 'dois',
        "attributes": {
          "doi": "#{ENV['DOI_PREFIX']}/#{@work.id}",
          "creators": creators_hash,
          "titles": [{ title: @work.title&.first }],
          "publisher": @work.publisher&.first || 'Ruhr-University Bochum',
          "publicationYear": Date.today.year,
          "types": {
            "resourceTypeGeneral": @work.resource_type&.first
          }
        }
      }
    }
    request.body = body.to_json
    response = http.request(request)

    raise Net::HTTPFatalError.new response.message, response unless response.is_a?(Net::HTTPSuccess)

    parsed_response = JSON.parse(response.body)

    attributes = parsed_response['data']['attributes']

    raise Net::HTTPFatalError.new "No Attributes Found", response unless attributes.present?
    attributes
  end

  def update_work(attributes)
    # attributes is a hash containing the DOI and the date published
    # attributes = {
    #   'doi' => "#{ENV['DOI_PREFIX']}/#{@work.id}",
    #   'created' => '2024-10-12'
    # }
    complex_identifier = { identifier: attributes['doi'], scheme: 'DOI' } 
    complex_date = {date: attributes['created'].to_date.strftime('%d/%m/%Y'), description: 'Published'}
    user = ::User.find_by_user_key(@work.depositor)

    @work.complex_identifier = @work.complex_identifier + [complex_identifier]
    @work.complex_date = @work.complex_date + [complex_date]
    @work.save
    Hyrax.publisher.publish('object.metadata.updated', object: @work, user: user)
  end
end