# frozen_string_literal: true
module Hyrax
  module Workflow
    ##
    # This is a built in function for workflow, so that a workflow action can be created that
    # removes the creators the ability to alter it.
    module RevokeEditFromCrcManager
      def self.call(target:, **) 
        model = target.try(:model) || target 
        collection = model.parent_collections.first

        group_key = "#{collection.collection_type.title.parameterize(separator: '_')}_manager"
        crc_manager_role = Role.find_by(is_crc_manager: true)

        model.edit_groups = model.edit_groups.to_a - Array.wrap(group_key) # += works in Ruby 2.6+
        model.edit_users = model.edit_users.to_a - crc_manager_role.users&.pluck(:email)
        model.try(:permission_manager)&.acl&.save

        RevokeEditFromGroupJob.perform_later(model, group_key)
      end
    end
  end
end