# frozen_string_literal: true
require 'faraday/multipart'

require "shrine/storage/s3"
require "valkyrie/storage/shrine"
require "valkyrie/shrine/checksum/s3"

if ENV.fetch("REGISTER_VALKYRIE", "true").to_s.downcase == "true"
  Valkyrie::MetadataAdapter.register(
    Valkyrie::Persistence::Postgres::MetadataAdapter.new,
    :pg_metadata
  )

  Valkyrie.config.metadata_adapter = ENV.fetch('VALKYRIE_METADATA_ADAPTER', "") { :pg_metadata }.to_sym

  shrine_s3_options = {
    endpoint: ENV.fetch("S3_ENDPOINT", ""),
    bucket: ENV.fetch("S3_FILE_UPLOAD_BUCKET", ""),
    region: ENV.fetch("S3_REGION", "rub-zg"),
    access_key_id: (ENV["S3_ACCESS_KEY"] || ENV["MINIO_ACCESS_KEY"]),
    secret_access_key: (ENV["S3_SECRET_KEY"] || ENV["MINIO_SECRET_KEY"]),
    force_path_style: true
  }

  Valkyrie::StorageAdapter.register(
    Valkyrie::Storage::Shrine.new(Shrine::Storage::S3.new(**shrine_s3_options), nil, ::S3PathGenerator),
    :repository_s3
  )

  Valkyrie::StorageAdapter.register(
    Valkyrie::Storage::VersionedDisk.new(base_path: Rails.root.join("storage", "files"),
                                         file_mover: FileUtils.method(:cp)),
    :versioned_disk_storage
  )

  Valkyrie.config.storage_adapter  = ENV.fetch('VALKYRIE_STORAGE_ADAPTER', "") { :versioned_disk_storage }.to_sym

  Valkyrie.config.indexing_adapter = :solr_index

  custom_queries = [Hyrax::CustomQueries::Navigators::CollectionMembers,
                    Hyrax::CustomQueries::Navigators::ChildCollectionsNavigator,
                    Hyrax::CustomQueries::Navigators::ParentCollectionsNavigator,
                    Hyrax::CustomQueries::Navigators::ChildFileSetsNavigator,
                    Hyrax::CustomQueries::Navigators::ChildWorksNavigator,
                    Hyrax::CustomQueries::Navigators::ParentWorkNavigator,
                    Hyrax::CustomQueries::Navigators::FindFiles,
                    Hyrax::CustomQueries::FindAccessControl,
                    Hyrax::CustomQueries::FindCollectionsByType,
                    Hyrax::CustomQueries::FindFileMetadata,
                    Hyrax::CustomQueries::FindIdsByModel,
                    Hyrax::CustomQueries::FindManyByAlternateIds,
                    Hyrax::CustomQueries::FindModelsByAccess,
                    Hyrax::CustomQueries::FindCountBy,
                    Hyrax::CustomQueries::FindByDateRange,
                    Hyrax::CustomQueries::FindBySourceIdentifier]
  custom_queries.each do |handler|
    Hyrax.query_service.custom_queries.register_query_handler(handler)
  end
end
