# frozen_string_literal: true

Bulkrax.setup do |config|
  # Add local parsers
  config.parsers += [
    { name: 'CRC folder parser - Build csv from directory data', class_name: 'Bulkrax::CrcFolderParser', partial: 'crc_folder_fields' },
    { name: 'CSV from S3 - ReSeed CSV parser for work (Datasets) from local S3', class_name: 'Bulkrax::RubCsvParser', partial: 'rub_csv_fields' }
  ]

  # Restoring the default work type from the old configuration (you can adjust this if necessary)
  config.default_work_type = 'Crc1280Experiment'
  config.collection_model_class = 'Hyrax::PcdmCollection'
  config.file_model_class = 'Hyrax::FileSet'
  # WorkType to use as the default if none is specified in the import
  # Default is the first returned by Hyrax.config.curation_concerns, stringified
  # config.default_work_type = "MyWork"

  # Factory Class to use when generating and saving objects
  # config.object_factory = Bulkrax::ObjectFactory
  # Use this for a Postgres-backed Valkyrized Hyrax
  config.object_factory = Bulkrax::ValkyrieObjectFactory

  # Path to store pending imports
  # config.import_path = 'tmp/imports'

  # Path to store exports before download
  # config.export_path = 'tmp/exports'

  # Server name for oai request header
  # config.server_name = 'my_server@name.com'

  # Field mappings for different parsers
  config.field_mappings = {
    "Bulkrax::CrcFolderParser" => {
      "date_created" => { from: ["date"] },
      "description" => { from: ["description"] },
      "identifier" => { from: ["identifier"] },
      "language" => { from: ["language"], parsed: true },
      "publisher" => { from: ["publisher"] },
      "rights_statement" => { from: ["rights"] },
      "source" => { from: ["source"], source_identifier: true },
      "subject" => { from: ["subject"], parsed: true },
      "title" => { from: ["title"] },
      "resource_type" => { from: ["type"], parsed: true },
      "remote_files" => { from: ["thumbnail_url"], parsed: true },
      "abstract" => { from: ["abstract"] },
      "keyword" => { from: ["keyword"] },
      "crc_resource_type" => { from: ["crc resource type"] },
      "crc_work_type" => { from: ["crc work type"] },
      "folder_name" => { from: ["folder_name"] },
      "experiment_description" => { from: ["experiment_description"] },
      "for_complex_identifier" => { from: ["for_complex_identifier"] },
      "for_complex_type" => { from: ["for_complex_type"] },
      'parents' => { from: ['parents'], related_parents_field_mapping: true },
      'children' => { from: ['children'], related_children_field_mapping: true }
    },

    "Bulkrax::RubCsvParser" => {
      "title" => { from: ["title"], source_identifier: true},
      "description" => { from: ["description"] },
      "resource_type" => { from: ["resource_type"], parsed: true },
      "keyword" => { from: ["keyword"] },
      "alternative_title" => { from: ["alternative_title"] },
      "subject" => { from: ["subject"], parsed: true },
      "language" => { from: ["language"], parsed: true },
      "software_version" => { from: ["software_version"] },
      "dataset_path" => {from: ["dataset_path"]}
    }
  }

  # NOTE: Creating Collections using the collection_field_mapping will no longer be supported as of Bulkrax version 3.0.
  #       Please configure Bulkrax to use related_parents_field_mapping and related_children_field_mapping instead.
  # Field_mapping for establishing a collection relationship (FROM work TO collection)
  # This value IS NOT used for OAI, so setting the OAI parser here will have no effect
  # The mapping is supplied per Entry, provide the full class name as a string, eg. 'Bulkrax::CsvEntry'
  # The default value for CSV is collection
  # Add/replace parsers, for example:
  # config.collection_field_mapping['Bulkrax::RdfEntry'] = 'http://opaquenamespace.org/ns/set'

  # Field mappings
  # Create a completely new set of mappings by replacing the whole set as follows
  #   config.field_mappings = {
  #     "Bulkrax::OaiDcParser" => { **individual field mappings go here*** }
  #   }

  # Add to, or change existing mappings as follows
  #   e.g. to exclude date
  #   config.field_mappings["Bulkrax::OaiDcParser"]["date"] = { from: ["date"], excluded: true  }
  #
  #   e.g. to import parent-child relationships
  #   config.field_mappings['Bulkrax::CsvParser']['parents'] = { from: ['parents'], related_parents_field_mapping: true }
  #   config.field_mappings['Bulkrax::CsvParser']['children'] = { from: ['children'], related_children_field_mapping: true }
  #   (For more info on importing relationships, see Bulkrax Wiki: https://github.com/samvera-labs/bulkrax/wiki/Configuring-Bulkrax#parent-child-relationship-field-mappings)
  #
  # #   e.g. to add the required source_identifier field
  #   #   config.field_mappings["Bulkrax::CsvParser"]["source_id"] = { from: ["old_source_id"], source_identifier: true, search_field: 'source_id_sim' }
  # If you want Bulkrax to fill in source_identifiers for you, see below

  # To duplicate a set of mappings from one parser to another
  #   config.field_mappings["Bulkrax::OaiOmekaParser"] = {}
  #   config.field_mappings["Bulkrax::OaiDcParser"].each {|key,value| config.field_mappings["Bulkrax::OaiOmekaParser"][key] = value }

  # Should Bulkrax make up source identifiers for you? This allow round tripping
  # and download errored entries to still work, but does mean if you upload the
  # same source record in two different files you WILL get duplicates.
  # It is given two aruguments, self at the time of call and the index of the reocrd
  #    config.fill_in_blank_source_identifiers = ->(parser, index) { "b-#{parser.importer.id}-#{index}"}
  # or use a uuid
  #    config.fill_in_blank_source_identifiers = ->(parser, index) { SecureRandom.uuid }

  # Properties that should not be used in imports/exports. They are reserved for use by Hyrax.
  # config.reserved_properties += ['my_field']

  # List of Questioning Authority properties that are controlled via YAML files in
  # the config/authorities/ directory. For example, the :rights_statement property
  # is controlled by the active terms in config/authorities/rights_statements.yml
  # Defaults: 'rights_statement' and 'license'
  # config.qa_controlled_properties += ['my_field']

  # Specify the delimiter regular expression for splitting an attribute's values into a multi-value array.
  # config.multi_value_element_split_on = /\s*[:;|]\s*/.freeze

  # Specify the delimiter for joining an attribute's multi-value array into a string.  Note: the
  # specific delimeter should likely be present in the multi_value_element_split_on expression.
  # config.multi_value_element_join_on = ' | '
end
