Rails.application.routes.draw do
  concern :range_searchable, BlacklightRangeLimit::Routes::RangeSearchable.new
  mount Bulkrax::Engine, at: '/'
  mount Riiif::Engine => 'images', as: :riiif if Hyrax.config.iiif_image_server?
        mount BrowseEverything::Engine => '/browse'

  mount Blacklight::Engine => '/'
  
  concern :searchable, Blacklight::Routes::Searchable.new

  resource :catalog, only: [:index], as: 'catalog', path: '/catalog', controller: 'catalog' do
    concerns :searchable
    concerns :range_searchable
    get :download_search_results, on: :collection
  end

  devise_for :users, controllers: { omniauth_callbacks: 'callbacks' }
  mount Hydra::RoleManagement::Engine => '/'

  devise_scope :user do
    get "users/system_sign_in", :to => "sessions#system_sign_in"
    get 'users/:id', :to => "users#show"
    post "users/accept_agreement", :to => "users#accept_agreement"
    delete "users/discard_agreement", :to => "users#discard_agreement"
  end

  get 'dashboard/profiles/:id', :to => 'profiles#show'
  get 'agreements/deposite_agreement',to: "agreements#deposite_agreement" , as: :deposite_agreement

  authenticate :user, lambda { |u| u.admin? } do
    require 'sidekiq/web'
    mount Sidekiq::Web => '/sidekiq'
  end

  mount Qa::Engine => '/authorities'
  mount Hyrax::Engine, at: '/'
  resources :welcome, only: 'index'
  root 'hyrax/homepage#index'
  curation_concerns_basic_routes
  concern :exportable, Blacklight::Routes::Exportable.new

  resources :solr_documents, only: [:show], path: '/catalog', controller: 'catalog' do
    concerns :exportable
  end

  resources :bookmarks do
    concerns :exportable

    collection do
      delete 'clear'
    end
  end

  resources :download_all, only: [:show] do
    get 'button_ready/:id', :to => "download_all#button_ready", on: :collection
  end
  # For details on the DSL available within this file, see https://guides.rubyonrails.org/routing.html

end


Hyrax::Engine.routes.draw do

  scope :concern, module: :crc1280_experiments do
    resources :crc1280_experiments, only: [] do
      resources :complex_sessions do
        get :validate_session_title, on: :collection
      end
      resources :complex_subjects do
        get :validate_subject_title, on: :collection
      end
      resources :complex_modalities do
        get :validate_modality_title, on: :collection
      end
    end
  end
end

Bulkrax::Engine.routes.draw do
  concern :range_searchable, BlacklightRangeLimit::Routes::RangeSearchable.new
  post 'rerun_failed_entries', to: "rerun_importers#rerun_failed_entries"
  post 'rerun_pending_entries', to: "rerun_importers#rerun_panding_entries"
  post 'marked_as_complete', to: "rerun_importers#marked_as_complete"
  get 'importers/:importer_id/verify_and_generate_work/:entry_id', to: "importers#verify_and_generate_work"
end