# frozen_string_literal: true
namespace :rdms do
  namespace :crc_1280_collection do
    desc "Create CRC 1280 Collection Types and CRC 1280 Collection"
    task create: :environment do
      crc_collection_title = ENV.fetch('CRC_1280_COLLECTION', "CRC 1280")
      collection_type = Hyrax::CollectionType.find_or_create_by(title: crc_collection_title)
      crc_1280_collections = collection_type.collections.select{ |t| t.title == [crc_collection_title] }

      admin_role = Role.find_by(name: "admin")
      admin_user = admin_role&.users&.first

      if admin_user.present?
        unless crc_1280_collections.any?
          collection = Hyrax.config.collection_class.new(title: [crc_collection_title], source:[SecureRandom.uuid], collection_type_gid: collection_type.to_global_id)
          change_set = Hyrax::ChangeSet.for(collection)
          result = Hyrax::Transactions::Container['change_set.create_collection'].with_step_args(
            'change_set.set_user_as_depositor' => { user: admin_user },
            'collection_resource.apply_collection_type_permissions' => { user: admin_user }
          )
          .call(change_set)
        end
      else
        puts "Collection not created, No Admin user exist"
      end
    end
  end
end